@@ -1,5 +1,3 @@
-# coding=utf-8
-from __future__ import unicode_literals
 from .. import Provider as AddressProvider
 
 
@@ -22,10 +20,12 @@ class Provider(AddressProvider):
         "{{province}}{{city}}{{district}}{{street_address}} {{postcode}}",)
 
     provinces = (
-        "内蒙古自治区", "山西省", "河北省", "吉林省", "江苏省", "辽宁省", "黑龍江省",
+        "北京市", "上海市", "天津市", "重庆市",
+        "内蒙古自治区", "山西省", "河北省", "吉林省", "江苏省", "辽宁省", "黑龙江省",
         "安徽省", "山东省", "浙江省", "江西省", "福建省", "湖南省", "湖北省",
         "河南省", "广东省", "广西壮族自治区", "贵州省", "海南省", "四川省", "云南省",
         "陕西省", "甘肃省", "宁夏回族自治区", "青海省", "新疆维吾尔自治区", "西藏自治区",
+        "台湾省", "香港特别行政区", "澳门特别行政区",
     )
     districts = (
         "西夏", "永川", "秀英", "高港", "清城", "兴山", "锡山", "清河",
