@@ -1,8 +1,7 @@
-# coding=utf-8
-from __future__ import unicode_literals
-from .. import Provider as InternetProvider
 from faker.utils.decorators import slugify
 
+from .. import Provider as InternetProvider
+
 
 class Provider(InternetProvider):
     user_name_formats = (
