@@ -1,8 +1,6 @@
-# coding=utf-8
-from __future__ import unicode_literals
 from collections import OrderedDict
-from .. import Provider as PersonProvider
 
+from .. import Provider as PersonProvider
 
 # Data source
 #
